# Source code of paper "Attention-based Domain Adaptation for Time Series Forecasting"

## Filetree
* tslib: time series analysis infrastructure
* network: basic neural network structures
* estimator: high-level nerual architectures
* engine: trainer and evaluators
* dataset.py: dataset objects for training


## Reproducibility
* Synthetic experiments in fewshot.ipynb
* Real experiments for source dataset "a" and target dataset "b" in [a2b].ipynb
* Figure 3,4,8 in fewshot.ipynb
* Figure 6,9 in E2T.ipynb